==> com.liferay.frontend.editor.tinymce.web-5.0.2.jar: META-INF/resources/_diffs/langs/tr_TR.js <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

tinymce.addI18n('tr_TR', {
	Cut: 'Kes',
	'Heading 5': 'Ba\u015fl\u0131k 5',
	'Header 2': 'Ba\u015fl\u0131k 2',
	"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X/C/V keyboard shortcuts instead.":
		'Taray\u0131c\u0131n\u0131z panoya direk eri\u015fimi desteklemiyor. L\u00fctfen Ctrl+X/C/V klavye k\u0131sayollar\u0131n\u0131 kullan\u0131n.',
	'Heading 4': 'Ba\u015fl\u0131k 4',
	Div: 'Div',
	'Heading 2': 'Ba\u015fl\u0131k 2',
	Paste: 'Yap\u0131\u015ft\u0131r',
	Close: 'Kapat',
	'Font Family': 'Yaz\u0131tipi Ailesi',
	Pre: '\u00d6n',
	'Align right': 'Sa\u011fa hizala',
	'New document': 'Yeni dok\u00fcman',
	Blockquote: 'Al\u0131nt\u0131',
	'Numbered list': 'S\u0131ral\u0131 liste',
	'Heading 1': 'Ba\u015fl\u0131k 1',
	Headings: 'Ba\u015fl\u0131klar',
	'Increase indent': 'Girintiyi art\u0131r',
	Formats: 'Bi\u00e7imler',
	Headers: 'Ba\u015fl\u0131klar',
	'Select all': 'T\u00fcm\u00fcn\u00fc se\u00e7',
	'Header 3': 'Ba\u015fl\u0131k 3',
	Blocks: 'Bloklar',
	Undo: 'Geri Al',
	Strikethrough: '\u00dcst\u00fc \u00e7izili',
	'Bullet list': 'S\u0131ras\u0131z liste',
	'Header 1': 'Ba\u015fl\u0131k 1',
	Superscript: '\u00dcst simge',
	'Clear formatting': 'Bi\u00e7imi temizle',
	'Font Sizes': 'Yaz\u0131tipi B\u00fcy\u00fckl\u00fc\u011f\u00fc',
	Subscript: 'Alt simge',
	'Header 6': 'Ba\u015fl\u0131k 6',
	Redo: 'Yinele',
	Paragraph: 'Paragraf',
	Ok: 'Tamam',
	Bold: 'Kal\u0131n',
	Code: 'Kod',
	Italic: '\u0130talik',
	'Align center': 'Ortala',
	'Header 5': 'Ba\u015fl\u0131k 5',
	'Heading 6': 'Ba\u015fl\u0131k 6',
	'Heading 3': 'Ba\u015fl\u0131k 3',
	'Decrease indent': 'Girintiyi azalt',
	'Header 4': 'Ba\u015fl\u0131k 4',
	'Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.':
		'D\u00fcz metin modunda yap\u0131\u015ft\u0131r. Bu se\u00e7ene\u011fi kapatana kadar i\u00e7erikler d\u00fcz metin olarak yap\u0131\u015ft\u0131r\u0131l\u0131r.',
	Underline: 'Alt\u0131 \u00e7izili',
	Cancel: '\u0130ptal',
	Justify: '\u0130ki yana yasla',
	Inline: 'Sat\u0131r i\u00e7i',
	Copy: 'Kopyala',
	'Align left': 'Sola hizala',
	'Visual aids': 'G\u00f6rsel ara\u00e7lar',
	'Lower Greek': 'K\u00fc\u00e7\u00fck Yunan alfabesi',
	Square: 'Kare',
	Default: 'Varsay\u0131lan',
	'Lower Alpha': 'K\u00fc\u00e7\u00fck ABC',
	Circle: 'Daire',
	Disc: 'Disk',
	'Upper Alpha': 'B\u00fcy\u00fck ABC',
	'Upper Roman': 'B\u00fcy\u00fck Roman alfabesi',
	'Lower Roman': 'K\u00fc\u00e7\u00fck Roman alfabesi',
	Name: '\u0130sim',
	Anchor: '\u00c7apa',
	'You have unsaved changes are you sure you want to navigate away?':
		'Kaydedilmemi\u015f de\u011fi\u015fiklikler var, sayfadan ayr\u0131lmak istedi\u011finize emin misiniz?',
	'Restore last draft': 'Son tasla\u011f\u0131 kurtar',
	'Special character': '\u00d6zel karakter',
	'Source code': 'Kaynak kodu',
	Color: 'Renk',
	'Right to left': 'Sa\u011fdan sola',
	'Left to right': 'Soldan sa\u011fa',
	Emoticons: 'G\u00fcl\u00fcc\u00fckler',
	Robots: 'Robotlar',
	'Document properties': 'Dok\u00fcman \u00f6zellikleri',
	Title: 'Ba\u015fl\u0131k',
	Keywords: 'Anahtar kelimeler',
	Encoding: 'Kodlama',
	Description: 'A\u00e7\u0131klama',
	Author: 'Yazar',
	Fullscreen: 'Tam ekran',
	'Horizontal line': 'Yatay \u00e7izgi',
	'Horizontal space': 'Yatay bo\u015fluk',
	'Insert/edit image': 'Resim ekle/d\u00fczenle',
	General: 'Genel',
	Advanced: 'Geli\u015fmi\u015f',
	Source: 'Kaynak',
	Border: '\u00c7er\u00e7eve',
	'Constrain proportions': 'En - Boy oran\u0131n\u0131 koru',
	'Vertical space': 'Dikey bo\u015fluk',
	'Image description': 'Resim a\u00e7\u0131klamas\u0131',
	Style: 'Stil',
	Dimensions: 'Boyutlar',
	'Insert image': 'Resim ekle',
	'Insert date/time': 'Tarih / Zaman ekle',
	'Remove link': 'Ba\u011flant\u0131y\u0131 kald\u0131r',
	Url: 'Url',
	'Text to display': 'G\u00f6r\u00fcnen yaz\u0131',
	Anchors: '\u00c7apalar',
	'Insert link': 'Ba\u011flant\u0131 ekle',
	'New window': 'Yeni pencere',
	None: 'Hi\u00e7biri',
	'The URL you entered seems to be an external link. Do you want to add the required http:// prefix?':
		'Girdi\u011finiz URL bir d\u0131\u015f ba\u011flant\u0131 gibi g\u00f6z\u00fck\u00fcyor. Gerekli olan http:// \u00f6nekini eklemek ister misiniz?',
	Target: 'Hedef',
	'The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?':
		'Girdi\u011finiz URL bir eposta adresi gibi g\u00f6z\u00fck\u00fcyor. Gerekli olan mailto: \u00f6nekini eklemek ister misiniz?',
	'Insert/edit link': 'Ba\u011flant\u0131 ekle/d\u00fczenle',
	'Insert/edit video': 'Video ekle/d\u00fczenle',
	Poster: 'Poster',
	'Alternative source': 'Alternatif kaynak',
	'Paste your embed code below:':
		'Medya g\u00f6mme kodunu buraya yap\u0131\u015ft\u0131r:',
	'Insert video': 'Video ekle',
	Embed: 'G\u00f6mme',
	'Nonbreaking space': 'B\u00f6l\u00fcnemez bo\u015fluk',
	'Page break': 'Sayfa sonu',
	'Paste as text': 'Metin olarak yap\u0131\u015ft\u0131r',
	Preview: '\u00d6nizleme',
	Print: 'Yazd\u0131r',
	Save: 'Kaydet',
	'Could not find the specified string.':
		'Herhangi bir sonu\u00e7 bulunamad\u0131.',
	Replace: 'De\u011fi\u015ftir',
	Next: 'Sonraki',
	'Whole words': 'Tam s\u00f6zc\u00fckler',
	'Find and replace': 'Bul ve de\u011fi\u015ftir',
	'Replace with': 'Bununla de\u011fi\u015ftir',
	Find: 'Bul',
	'Replace all': 'T\u00fcm\u00fcn\u00fc de\u011fi\u015ftir',
	'Match case': 'B\u00fcy\u00fck / K\u00fc\u00e7\u00fck harfe duyarl\u0131',
	Prev: '\u00d6nceki',
	Spellcheck: 'Yaz\u0131m denetimi',
	Finish: 'Bitir',
	'Ignore all': 'T\u00fcm\u00fcn\u00fc yoksay',
	Ignore: 'Yoksay',
	'Add to Dictionary': 'S\u00f6zl\u00fc\u011fe ekle',
	'Insert row before': '\u00d6ncesine yeni sat\u0131r ekle',
	Rows: 'Sat\u0131rlar',
	Height: 'Y\u00fckseklik',
	'Paste row after': 'Sonras\u0131na sat\u0131r  yap\u0131\u015ft\u0131r',
	Alignment: 'Hizalama',
	'Border color': 'Kenarl\u0131k Rengi',
	'Column group': 'S\u00fctun grubu',
	Row: 'Sat\u0131r',
	'Insert column before': '\u00d6ncesine yeni s\u00fctun ekle',
	'Split cell': 'H\u00fccreleri ay\u0131r',
	'Cell padding': 'H\u00fccre i\u00e7 bo\u015flu\u011fu',
	'Cell spacing': 'H\u00fccre aral\u0131\u011f\u0131',
	'Row type': 'Sat\u0131r tipi',
	'Insert table': 'Tablo ekle',
	Body: 'G\u00f6vde',
	Caption: 'Ba\u015fl\u0131k',
	Footer: 'Alt',
	'Delete row': 'Sat\u0131r\u0131 sil',
	'Paste row before': '\u00d6ncesine sat\u0131r yap\u0131\u015ft\u0131r',
	Scope: 'Kapsam',
	'Delete table': 'Tabloyu sil',
	'H Align': 'Yatay Hizalama',
	Top: '\u00dcst',
	'Header cell': 'Ba\u015fl\u0131k h\u00fccresi',
	Column: 'S\u00fctun',
	'Row group': 'Sat\u0131r grubu',
	Cell: 'H\u00fccre',
	Middle: 'Orta',
	'Cell type': 'H\u00fccre tipi',
	'Copy row': 'Sat\u0131r\u0131 kopyala',
	'Row properties': 'Sat\u0131r \u00f6zellikleri',
	'Table properties': 'Tablo \u00f6zellikleri',
	Bottom: 'Alt',
	'V Align': 'Dikey Hizalama',
	Header: 'Ba\u015fl\u0131k',
	Right: 'Sa\u011f',
	'Insert column after': 'Sonras\u0131na yeni s\u00fctun ekle',
	Cols: 'S\u00fctunlar',
	'Insert row after': 'Sonras\u0131na yeni sat\u0131r ekle',
	Width: 'Geni\u015flik',
	'Cell properties': 'H\u00fccre \u00f6zellikleri',
	Left: 'Sol',
	'Cut row': 'Sat\u0131r\u0131 kes',
	'Delete column': 'S\u00fctunu sil',
	Center: 'Orta',
	'Merge cells': 'H\u00fccreleri birle\u015ftir',
	'Insert template': '\u015eablon ekle',
	Templates: '\u015eablonlar',
	'Background color': 'Arkaplan rengi',
	'Custom...': '\u00d6zel',
	'Custom color': '\u00d6zel Renk',
	'No color': 'Renk Yok',
	'Text color': 'Yaz\u0131 rengi',
	'Show blocks': 'Bloklar\u0131 g\u00f6r\u00fcnt\u00fcle',
	'Show invisible characters': 'G\u00f6r\u00fcnmez karakterleri g\u00f6ster',
	'Words: {0}': 'Kelime: {0}',
	Insert: 'Ekle',
	File: 'Dosya',
	Edit: 'D\u00fczenle',
	'Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help':
		'Zengin Metin Alan\u0131. Men\u00fc i\u00e7in ALT-F9 k\u0131sayolunu kullan\u0131n. Ara\u00e7 \u00e7ubu\u011fu i\u00e7in ALT-F10 k\u0131sayolunu kullan\u0131n. Yard\u0131m i\u00e7in ALT-0 k\u0131sayolunu kullan\u0131n.',
	Tools: 'Ara\u00e7lar',
	View: 'G\u00f6r\u00fcnt\u00fcle',
	Table: 'Tablo',
	Format: 'Bi\u00e7im',
});

==> com.liferay.frontend.editor.tinymce.web-5.0.15.jar: META-INF/resources/_diffs/langs/tr_TR.js <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

tinymce.addI18n('tr_TR', {
	'Cut': 'Kes',
	'Heading 5': 'Ba\u015fl\u0131k 5',
	'Header 2': 'Ba\u015fl\u0131k 2',
	"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X/C/V keyboard shortcuts instead.":
		'Taray\u0131c\u0131n\u0131z panoya direk eri\u015fimi desteklemiyor. L\u00fctfen Ctrl+X/C/V klavye k\u0131sayollar\u0131n\u0131 kullan\u0131n.',
	'Heading 4': 'Ba\u015fl\u0131k 4',
	'Div': 'Div',
	'Heading 2': 'Ba\u015fl\u0131k 2',
	'Paste': 'Yap\u0131\u015ft\u0131r',
	'Close': 'Kapat',
	'Font Family': 'Yaz\u0131tipi Ailesi',
	'Pre': '\u00d6n',
	'Align right': 'Sa\u011fa hizala',
	'New document': 'Yeni dok\u00fcman',
	'Blockquote': 'Al\u0131nt\u0131',
	'Numbered list': 'S\u0131ral\u0131 liste',
	'Heading 1': 'Ba\u015fl\u0131k 1',
	'Headings': 'Ba\u015fl\u0131klar',
	'Increase indent': 'Girintiyi art\u0131r',
	'Formats': 'Bi\u00e7imler',
	'Headers': 'Ba\u015fl\u0131klar',
	'Select all': 'T\u00fcm\u00fcn\u00fc se\u00e7',
	'Header 3': 'Ba\u015fl\u0131k 3',
	'Blocks': 'Bloklar',
	'Undo': 'Geri Al',
	'Strikethrough': '\u00dcst\u00fc \u00e7izili',
	'Bullet list': 'S\u0131ras\u0131z liste',
	'Header 1': 'Ba\u015fl\u0131k 1',
	'Superscript': '\u00dcst simge',
	'Clear formatting': 'Bi\u00e7imi temizle',
	'Font Sizes': 'Yaz\u0131tipi B\u00fcy\u00fckl\u00fc\u011f\u00fc',
	'Subscript': 'Alt simge',
	'Header 6': 'Ba\u015fl\u0131k 6',
	'Redo': 'Yinele',
	'Paragraph': 'Paragraf',
	'Ok': 'Tamam',
	'Bold': 'Kal\u0131n',
	'Code': 'Kod',
	'Italic': '\u0130talik',
	'Align center': 'Ortala',
	'Header 5': 'Ba\u015fl\u0131k 5',
	'Heading 6': 'Ba\u015fl\u0131k 6',
	'Heading 3': 'Ba\u015fl\u0131k 3',
	'Decrease indent': 'Girintiyi azalt',
	'Header 4': 'Ba\u015fl\u0131k 4',
	'Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.':
		'D\u00fcz metin modunda yap\u0131\u015ft\u0131r. Bu se\u00e7ene\u011fi kapatana kadar i\u00e7erikler d\u00fcz metin olarak yap\u0131\u015ft\u0131r\u0131l\u0131r.',
	'Underline': 'Alt\u0131 \u00e7izili',
	'Cancel': '\u0130ptal',
	'Justify': '\u0130ki yana yasla',
	'Inline': 'Sat\u0131r i\u00e7i',
	'Copy': 'Kopyala',
	'Align left': 'Sola hizala',
	'Visual aids': 'G\u00f6rsel ara\u00e7lar',
	'Lower Greek': 'K\u00fc\u00e7\u00fck Yunan alfabesi',
	'Square': 'Kare',
	'Default': 'Varsay\u0131lan',
	'Lower Alpha': 'K\u00fc\u00e7\u00fck ABC',
	'Circle': 'Daire',
	'Disc': 'Disk',
	'Upper Alpha': 'B\u00fcy\u00fck ABC',
	'Upper Roman': 'B\u00fcy\u00fck Roman alfabesi',
	'Lower Roman': 'K\u00fc\u00e7\u00fck Roman alfabesi',
	'Name': '\u0130sim',
	'Anchor': '\u00c7apa',
	'You have unsaved changes are you sure you want to navigate away?':
		'Kaydedilmemi\u015f de\u011fi\u015fiklikler var, sayfadan ayr\u0131lmak istedi\u011finize emin misiniz?',
	'Restore last draft': 'Son tasla\u011f\u0131 kurtar',
	'Special character': '\u00d6zel karakter',
	'Source code': 'Kaynak kodu',
	'Color': 'Renk',
	'Right to left': 'Sa\u011fdan sola',
	'Left to right': 'Soldan sa\u011fa',
	'Emoticons': 'G\u00fcl\u00fcc\u00fckler',
	'Robots': 'Robotlar',
	'Document properties': 'Dok\u00fcman \u00f6zellikleri',
	'Title': 'Ba\u015fl\u0131k',
	'Keywords': 'Anahtar kelimeler',
	'Encoding': 'Kodlama',
	'Description': 'A\u00e7\u0131klama',
	'Author': 'Yazar',
	'Fullscreen': 'Tam ekran',
	'Horizontal line': 'Yatay \u00e7izgi',
	'Horizontal space': 'Yatay bo\u015fluk',
	'Insert/edit image': 'Resim ekle/d\u00fczenle',
	'General': 'Genel',
	'Advanced': 'Geli\u015fmi\u015f',
	'Source': 'Kaynak',
	'Border': '\u00c7er\u00e7eve',
	'Constrain proportions': 'En - Boy oran\u0131n\u0131 koru',
	'Vertical space': 'Dikey bo\u015fluk',
	'Image description': 'Resim a\u00e7\u0131klamas\u0131',
	'Style': 'Stil',
	'Dimensions': 'Boyutlar',
	'Insert image': 'Resim ekle',
	'Insert date/time': 'Tarih / Zaman ekle',
	'Remove link': 'Ba\u011flant\u0131y\u0131 kald\u0131r',
	'Url': 'Url',
	'Text to display': 'G\u00f6r\u00fcnen yaz\u0131',
	'Anchors': '\u00c7apalar',
	'Insert link': 'Ba\u011flant\u0131 ekle',
	'New window': 'Yeni pencere',
	'None': 'Hi\u00e7biri',
	'The URL you entered seems to be an external link. Do you want to add the required http:// prefix?':
		'Girdi\u011finiz URL bir d\u0131\u015f ba\u011flant\u0131 gibi g\u00f6z\u00fck\u00fcyor. Gerekli olan http:// \u00f6nekini eklemek ister misiniz?',
	'Target': 'Hedef',
	'The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?':
		'Girdi\u011finiz URL bir eposta adresi gibi g\u00f6z\u00fck\u00fcyor. Gerekli olan mailto: \u00f6nekini eklemek ister misiniz?',
	'Insert/edit link': 'Ba\u011flant\u0131 ekle/d\u00fczenle',
	'Insert/edit video': 'Video ekle/d\u00fczenle',
	'Poster': 'Poster',
	'Alternative source': 'Alternatif kaynak',
	'Paste your embed code below:':
		'Medya g\u00f6mme kodunu buraya yap\u0131\u015ft\u0131r:',
	'Insert video': 'Video ekle',
	'Embed': 'G\u00f6mme',
	'Nonbreaking space': 'B\u00f6l\u00fcnemez bo\u015fluk',
	'Page break': 'Sayfa sonu',
	'Paste as text': 'Metin olarak yap\u0131\u015ft\u0131r',
	'Preview': '\u00d6nizleme',
	'Print': 'Yazd\u0131r',
	'Save': 'Kaydet',
	'Could not find the specified string.':
		'Herhangi bir sonu\u00e7 bulunamad\u0131.',
	'Replace': 'De\u011fi\u015ftir',
	'Next': 'Sonraki',
	'Whole words': 'Tam s\u00f6zc\u00fckler',
	'Find and replace': 'Bul ve de\u011fi\u015ftir',
	'Replace with': 'Bununla de\u011fi\u015ftir',
	'Find': 'Bul',
	'Replace all': 'T\u00fcm\u00fcn\u00fc de\u011fi\u015ftir',
	'Match case': 'B\u00fcy\u00fck / K\u00fc\u00e7\u00fck harfe duyarl\u0131',
	'Prev': '\u00d6nceki',
	'Spellcheck': 'Yaz\u0131m denetimi',
	'Finish': 'Bitir',
	'Ignore all': 'T\u00fcm\u00fcn\u00fc yoksay',
	'Ignore': 'Yoksay',
	'Add to Dictionary': 'S\u00f6zl\u00fc\u011fe ekle',
	'Insert row before': '\u00d6ncesine yeni sat\u0131r ekle',
	'Rows': 'Sat\u0131rlar',
	'Height': 'Y\u00fckseklik',
	'Paste row after': 'Sonras\u0131na sat\u0131r  yap\u0131\u015ft\u0131r',
	'Alignment': 'Hizalama',
	'Border color': 'Kenarl\u0131k Rengi',
	'Column group': 'S\u00fctun grubu',
	'Row': 'Sat\u0131r',
	'Insert column before': '\u00d6ncesine yeni s\u00fctun ekle',
	'Split cell': 'H\u00fccreleri ay\u0131r',
	'Cell padding': 'H\u00fccre i\u00e7 bo\u015flu\u011fu',
	'Cell spacing': 'H\u00fccre aral\u0131\u011f\u0131',
	'Row type': 'Sat\u0131r tipi',
	'Insert table': 'Tablo ekle',
	'Body': 'G\u00f6vde',
	'Caption': 'Ba\u015fl\u0131k',
	'Footer': 'Alt',
	'Delete row': 'Sat\u0131r\u0131 sil',
	'Paste row before': '\u00d6ncesine sat\u0131r yap\u0131\u015ft\u0131r',
	'Scope': 'Kapsam',
	'Delete table': 'Tabloyu sil',
	'H Align': 'Yatay Hizalama',
	'Top': '\u00dcst',
	'Header cell': 'Ba\u015fl\u0131k h\u00fccresi',
	'Column': 'S\u00fctun',
	'Row group': 'Sat\u0131r grubu',
	'Cell': 'H\u00fccre',
	'Middle': 'Orta',
	'Cell type': 'H\u00fccre tipi',
	'Copy row': 'Sat\u0131r\u0131 kopyala',
	'Row properties': 'Sat\u0131r \u00f6zellikleri',
	'Table properties': 'Tablo \u00f6zellikleri',
	'Bottom': 'Alt',
	'V Align': 'Dikey Hizalama',
	'Header': 'Ba\u015fl\u0131k',
	'Right': 'Sa\u011f',
	'Insert column after': 'Sonras\u0131na yeni s\u00fctun ekle',
	'Cols': 'S\u00fctunlar',
	'Insert row after': 'Sonras\u0131na yeni sat\u0131r ekle',
	'Width': 'Geni\u015flik',
	'Cell properties': 'H\u00fccre \u00f6zellikleri',
	'Left': 'Sol',
	'Cut row': 'Sat\u0131r\u0131 kes',
	'Delete column': 'S\u00fctunu sil',
	'Center': 'Orta',
	'Merge cells': 'H\u00fccreleri birle\u015ftir',
	'Insert template': '\u015eablon ekle',
	'Templates': '\u015eablonlar',
	'Background color': 'Arkaplan rengi',
	'Custom...': '\u00d6zel',
	'Custom color': '\u00d6zel Renk',
	'No color': 'Renk Yok',
	'Text color': 'Yaz\u0131 rengi',
	'Show blocks': 'Bloklar\u0131 g\u00f6r\u00fcnt\u00fcle',
	'Show invisible characters': 'G\u00f6r\u00fcnmez karakterleri g\u00f6ster',
	'Words: {0}': 'Kelime: {0}',
	'Insert': 'Ekle',
	'File': 'Dosya',
	'Edit': 'D\u00fczenle',
	'Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help':
		'Zengin Metin Alan\u0131. Men\u00fc i\u00e7in ALT-F9 k\u0131sayolunu kullan\u0131n. Ara\u00e7 \u00e7ubu\u011fu i\u00e7in ALT-F10 k\u0131sayolunu kullan\u0131n. Yard\u0131m i\u00e7in ALT-0 k\u0131sayolunu kullan\u0131n.',
	'Tools': 'Ara\u00e7lar',
	'View': 'G\u00f6r\u00fcnt\u00fcle',
	'Table': 'Tablo',
	'Format': 'Bi\u00e7im',
});
